@@ -47,35 +47,33 @@ typedef enum {
  * Information about a single column
  */
 typedef struct {
-	GtkObject         base;
-	char             *text;
-	GdkPixbuf        *pixbuf;
-	int               min_width;
-	int               width;
-	double            expansion;
-	short             x;
-	GCompareFunc      compare;
-	ETableSearchFunc  search;
-	unsigned int      is_pixbuf:1;
-	unsigned int      selected:1;
-	unsigned int      resizable:1;
-	unsigned int      disabled:1;
-	unsigned int      sortable:1;
-	unsigned int      groupable:1;
-	int               col_idx;
-	int               compare_col;
-	int               priority;
+	GtkObject    base;
+	char        *text;
+	GdkPixbuf   *pixbuf;
+	int          min_width;
+	int          width;
+	double       expansion;
+	short        x;
+	GCompareFunc compare;
+	unsigned int is_pixbuf:1;
+	unsigned int selected:1;
+	unsigned int resizable:1;
+	unsigned int disabled:1;
+	unsigned int sortable:1;
+	unsigned int groupable:1;
+	int          col_idx;
+	int          priority;
 
-	GtkJustification  justification;
+	GtkJustification justification;
 
-	ECell            *ecell;
+	ECell         *ecell;
 } ETableCol;
 
 typedef struct {
 	GtkObjectClass parent_class;
 } ETableColClass;
 
-GtkType    e_table_col_get_type         (void);
+GtkType        e_table_col_get_type        (void);
 ETableCol *e_table_col_new              (int           col_idx,
 					 const char   *text,
 					 double        expansion,
@@ -87,7 +85,7 @@ ETableCol *e_table_col_new              (int           col_idx,
 					 int           priority);
 ETableCol *e_table_col_new_with_pixbuf  (int           col_idx,
 					 const char   *text,
-					 GdkPixbuf    *pixbuf,
+					    GdkPixbuf *pixbuf,
 					 double        expansion,
 					 int           min_width,
 					 ECell        *ecell,
@@ -95,7 +93,7 @@ ETableCol *e_table_col_new_with_pixbuf  (int           col_idx,
 					 gboolean      resizable,
 					 gboolean      disabled,
 					 int           priority);
-void       e_table_col_destroy          (ETableCol    *etc);
+void           e_table_col_destroy         (ETableCol *etc);
 
 
 #ifdef __cplusplus
