@@ -1,28 +1,29 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * e-table-field-chooser-dialog.c
- * Copyright (C) 2000  Ximian, Inc.
- * Author: Chris Lahey <clahey@ximian.com>
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #include <config.h>
-#include <libgnomeui/gnome-stock.h>
 #include "e-table-field-chooser-dialog.h"
+#include "gal/util/e-i18n.h"
 
 static void e_table_field_chooser_dialog_init		(ETableFieldChooserDialog		 *card);
 static void e_table_field_chooser_dialog_class_init	(ETableFieldChooserDialogClass	 *klass);
@@ -38,6 +39,7 @@ enum {
 	ARG_0,
 	ARG_DND_CODE,
 	ARG_FULL_HEADER,
+	ARG_HEADER,
 };
 
 GtkType
@@ -49,6 +51,7 @@ e_table_field_chooser_dialog_get_type (void)
 		{
 			static const GtkTypeInfo table_field_chooser_dialog_info =
 			{
+
 				"ETableFieldChooserDialog",
 				sizeof (ETableFieldChooserDialog),
 				sizeof (ETableFieldChooserDialogClass),
@@ -86,6 +89,8 @@ e_table_field_chooser_dialog_class_init (ETableFieldChooserDialogClass *klass)
 				 GTK_ARG_READWRITE, ARG_DND_CODE);
 	gtk_object_add_arg_type ("ETableFieldChooserDialog::full_header", GTK_TYPE_OBJECT,
 				 GTK_ARG_READWRITE, ARG_FULL_HEADER);
+	gtk_object_add_arg_type ("ETableFieldChooserDialog::header", GTK_TYPE_OBJECT,
+				 GTK_ARG_READWRITE, ARG_HEADER);
 }
 
 static void
@@ -96,9 +101,10 @@ e_table_field_chooser_dialog_init (ETableFieldChooserDialog *e_table_field_choos
 	e_table_field_chooser_dialog->etfc = NULL;
 	e_table_field_chooser_dialog->dnd_code = g_strdup("");
 	e_table_field_chooser_dialog->full_header = NULL;
+	e_table_field_chooser_dialog->header = NULL;
 
 	gnome_dialog_append_buttons(GNOME_DIALOG(e_table_field_chooser_dialog),
-				    GNOME_STOCK_BUTTON_CLOSE,
+				    GTK_STOCK_CLOSE,
 				    NULL);
 
 	gtk_window_set_policy(GTK_WINDOW(e_table_field_chooser_dialog), FALSE, TRUE, FALSE);
@@ -109,12 +115,15 @@ e_table_field_chooser_dialog_init (ETableFieldChooserDialog *e_table_field_choos
 	gtk_object_set(GTK_OBJECT(widget),
 		       "dnd_code", e_table_field_chooser_dialog->dnd_code,
 		       "full_header", e_table_field_chooser_dialog->full_header,
+		       "header", e_table_field_chooser_dialog->header,
 		       NULL);
 	
 	gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(e_table_field_chooser_dialog)->vbox),
 			   widget, TRUE, TRUE, 0);
 
 	gtk_widget_show(GTK_WIDGET(widget));
+
+	gtk_window_set_title (GTK_WINDOW (e_table_field_chooser_dialog), _("Add a column..."));
 }
 
 GtkWidget*
@@ -128,9 +137,17 @@ static void
 e_table_field_chooser_dialog_destroy (GtkObject *object)
 {
 	ETableFieldChooserDialog *etfcd = E_TABLE_FIELD_CHOOSER_DIALOG (object);
-	g_free(etfcd->dnd_code);
+
+	g_free (etfcd->dnd_code);
+	etfcd->dnd_code = NULL;
+
 	if (etfcd->full_header)
 		gtk_object_unref(GTK_OBJECT(etfcd->full_header));
+	etfcd->full_header = NULL;
+
+	if (etfcd->header)
+		gtk_object_unref(GTK_OBJECT(etfcd->header));
+	etfcd->header = NULL;
 }
 
 static void
@@ -160,6 +177,20 @@ e_table_field_chooser_dialog_set_arg (GtkObject *object, GtkArg *arg, guint arg_
 				       "full_header", etfcd->full_header,
 				       NULL);
 		break;
+	case ARG_HEADER:
+		if (etfcd->header)
+			gtk_object_unref(GTK_OBJECT(etfcd->header));
+		if (GTK_VALUE_OBJECT(*arg))
+			etfcd->header = E_TABLE_HEADER(GTK_VALUE_OBJECT(*arg));
+		else
+			etfcd->header = NULL;
+		if (etfcd->header)
+			gtk_object_ref(GTK_OBJECT(etfcd->header));
+		if (etfcd->etfc)
+			gtk_object_set(GTK_OBJECT(etfcd->etfc),
+				       "header", etfcd->header,
+				       NULL);
+		break;
 	default:
 		break;
 	}
@@ -176,6 +207,9 @@ e_table_field_chooser_dialog_get_arg (GtkObject *object, GtkArg *arg, guint arg_
 	case ARG_FULL_HEADER:
 		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(etfcd->full_header);
 		break;
+	case ARG_HEADER:
+		GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(etfcd->header);
+		break;
 	default:
 		arg->type = GTK_TYPE_INVALID;
 		break;
