@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-header-item.c
  * Copyright 1999, 2000, 2001, Ximian, Inc.
  *
@@ -29,18 +29,19 @@
 #include <string.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkdnd.h>
-#include <libgnomeui/gnome-canvas.h>
-#include <libgnomeui/gnome-canvas-util.h>
-#include <libgnomeui/gnome-canvas-polygon.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
+#include <gtk/gtkimage.h>
+#include <libgnomecanvas/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas-util.h>
+#include <libgnomecanvas/gnome-canvas-polygon.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "gal/widgets/e-cursors.h"
 #include "gal/util/e-i18n.h"
 #include "gal/util/e-util.h"
 #include "gal/util/e-xml-utils.h"
+#include "gal/util/e-marshal.h"
 #include "gal/widgets/e-canvas.h"
 #include "gal/widgets/e-popup-menu.h"
-#include "gal/widgets/e-gui-utils.h"
 #include "e-table-header.h"
 #include "e-table-header-utils.h"
 #include "e-table-col-dnd.h"
@@ -99,7 +100,7 @@ enum {
 	ARG_TABLE_FONTSET,
 	ARG_SORT_INFO,
 	ARG_TABLE,
-	ARG_TREE
+	ARG_TREE,
 };
 
 enum {
@@ -136,9 +137,11 @@ ethi_destroy (GtkObject *object){
 
 	if (ethi->full_header)
 		gtk_object_unref (GTK_OBJECT(ethi->full_header));
+	ethi->full_header = NULL;
 
 	if (ethi->config)
 		gtk_object_destroy (GTK_OBJECT (ethi->config));
+	ethi->config = NULL;
 	
 	if (GTK_OBJECT_CLASS (ethi_parent_class)->destroy)
 		(*GTK_OBJECT_CLASS (ethi_parent_class)->destroy) (object);
@@ -211,8 +214,10 @@ ethi_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags
 			item->y1 = c1.y;
 			item->x2 = c2.x;
 			item->y2 = c2.y;
-
+#warning FOO BAA
+#if 0
 			gnome_canvas_group_child_bounds (GNOME_CANVAS_GROUP (item->parent), item);
+#endif
 		}
 	gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
 }
@@ -236,10 +241,10 @@ ethi_font_load (ETableHeaderItem *ethi, char *fontname)
 	GdkFont *font = NULL;
 
 	if (fontname != NULL)
-		font = gdk_fontset_load (fontname);
+	font = gdk_fontset_load (fontname);
 
 	if (font == NULL) {
-		font = GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas)->style->font;
+		font = gtk_style_get_font (GTK_WIDGET (GNOME_CANVAS_ITEM (ethi)->canvas)->style);
 		gdk_font_ref (font);
 	}
 	
@@ -398,7 +403,7 @@ ethi_find_col_by_x (ETableHeaderItem *ethi, int x)
 	const int cols = e_table_header_count (ethi->eth);
 	int x1 = 0;
 	int col;
-	
+
 	d(g_print ("%s:%d: x = %d, x1 = %d\n", __FUNCTION__, __LINE__, x, x1));
 
 	x1 += ethi->group_indent_width;
@@ -471,14 +476,13 @@ make_shaped_window_from_xpm (const char **xpm)
 	gdk_pixbuf_render_pixmap_and_mask (pixbuf, &pixmap, &bitmap, 128);
 	gdk_pixbuf_unref (pixbuf);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 	win = gtk_window_new (GTK_WINDOW_POPUP);
-	pix = gtk_pixmap_new (pixmap, bitmap);
+
+	pix = gtk_image_new_from_pixmap (pixmap, bitmap);
 	gtk_widget_realize (win);
 	gtk_container_add (GTK_CONTAINER (win), pix);
 	gtk_widget_shape_combine_mask (win, bitmap, 0, 0);
-	gtk_widget_pop_visual ();
 	gtk_widget_pop_colormap ();
 	
 	gdk_pixmap_unref (pixmap);
@@ -584,6 +588,7 @@ moved (ETableHeaderItem *ethi, guint col, guint model_col)
 }
 #endif
 
+
 static void
 do_drag_motion(ETableHeaderItem *ethi,
 	       GdkDragContext *context,
@@ -591,13 +596,10 @@ do_drag_motion(ETableHeaderItem *ethi,
 	       gint y,
 	       guint time,
 	       gboolean recreate)
-{
-	d(g_print("In do_drag_motion\n"));
-	d(g_print("x = %d, y = %d, ethi->width = %d, ethi->height = %d\n", x, y, ethi->width, ethi->height));
+  {
 	if ((x >= 0) && (x <= (ethi->width)) &&
 	    (y >= 0) && (y <= (ethi->height))){
 		int col;
-		d(g_print("In header\n"));
 		
 		col = ethi_find_col_by_x_nearest (ethi, x);
 
@@ -681,7 +683,9 @@ static void
 context_destroyed (gpointer data)
 {
 	ETableHeaderItem *ethi = data;
-	if (!GTK_OBJECT_DESTROYED (ethi)) {
+#warning FIXME
+	/* if (!GTK_OBJECT_DESTROYED (ethi)) */
+	{
 		ethi->last_drop_x       = 0;
 		ethi->last_drop_y       = 0;
 		ethi->last_drop_time    = 0;
@@ -721,12 +725,8 @@ ethi_drag_motion (GtkWidget *widget, GdkDragContext *context,
 
 	g_free (headertype);
 
-	d(g_print ("y = %d, widget->allocation.y = %d, GTK_LAYOUT (widget)->vadjustment->value = %f\n", y, widget->allocation.y, GTK_LAYOUT (widget)->vadjustment->value));
-
-#if 0
 	x -= widget->allocation.x;
 	y -= widget->allocation.y;
-#endif
 
 	if (x < 20)
 		direction |= ET_SCROLL_LEFT;
@@ -857,7 +857,6 @@ ethi_drag_drop (GtkWidget *canvas,
 		
 		if (col != -1) {
 			char *target = g_strdup_printf ("%s-%s", TARGET_ETABLE_COL_TYPE, ethi->dnd_code);
-			d(g_print ("ethi -  %s\n", target));
 			gtk_drag_get_data (canvas, context, gdk_atom_intern(target, FALSE), time);
 			g_free (target);
 		}
@@ -891,7 +890,7 @@ ethi_realize (GnomeCanvasItem *item)
 	window = GTK_WIDGET (item->canvas)->window;
 
 	if (!ethi->font)
-		ethi_font_set (ethi, GTK_WIDGET (item->canvas)->style->font);
+		ethi_font_set (ethi, gtk_style_get_font (GTK_WIDGET (item->canvas)->style));
 
 	/*
 	 * Now, configure DnD
@@ -1448,32 +1447,26 @@ ethi_popup_customize_view(GtkWidget *widget, EthiHeaderInfo *info)
 	}
 }
 
-static void
-free_popup_info (GtkWidget *w, EthiHeaderInfo *info)
-{
-	g_free (info);
-}
-
 /* Bit 1 is always disabled. */
 /* Bit 2 is disabled if not "sortable". */
 /* Bit 4 is disabled if we don't have a pointer to our table object. */
 static EPopupMenu ethi_context_menu [] = {
-	E_POPUP_ITEM (N_("Sort Ascending"),            GTK_SIGNAL_FUNC(ethi_popup_sort_ascending),  2),
-	E_POPUP_ITEM (N_("Sort Descending"),           GTK_SIGNAL_FUNC(ethi_popup_sort_descending), 2),
-	E_POPUP_ITEM (N_("Unsort"),                    GTK_SIGNAL_FUNC(ethi_popup_unsort),          0),
-	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Group By This Field"),       GTK_SIGNAL_FUNC(ethi_popup_group_field),     16),
-	E_POPUP_ITEM (N_("Group By Box"),              GTK_SIGNAL_FUNC(ethi_popup_group_box),       128),
-	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Remove This Column"),        GTK_SIGNAL_FUNC(ethi_popup_remove_column),   8),
-	E_POPUP_ITEM (N_("Add a Column..."),           GTK_SIGNAL_FUNC(ethi_popup_field_chooser),   0),
-	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Alignment"),                 GTK_SIGNAL_FUNC(ethi_popup_alignment),       128),
-	E_POPUP_ITEM (N_("Best Fit"),                  GTK_SIGNAL_FUNC(ethi_popup_best_fit),        2),
-	E_POPUP_ITEM (N_("Format Columns..."),         GTK_SIGNAL_FUNC(ethi_popup_format_columns),  128),
-	E_POPUP_SEPARATOR,
-	E_POPUP_ITEM (N_("Customize Current View..."), GTK_SIGNAL_FUNC(ethi_popup_customize_view),  4),
-	E_POPUP_TERMINATOR
+	{ N_("Sort Ascending"),            NULL, GTK_SIGNAL_FUNC(ethi_popup_sort_ascending),  NULL, 2},
+	{ N_("Sort Descending"),           NULL, GTK_SIGNAL_FUNC(ethi_popup_sort_descending), NULL, 2},
+	{ N_("Unsort"),                    NULL, GTK_SIGNAL_FUNC(ethi_popup_unsort),          NULL, 0},
+	{ "",                              NULL, GTK_SIGNAL_FUNC(NULL),                       NULL, 0},
+	{ N_("Group By This Field"),       NULL, GTK_SIGNAL_FUNC(ethi_popup_group_field),     NULL, 16},
+	{ N_("Group By Box"),              NULL, GTK_SIGNAL_FUNC(ethi_popup_group_box),       NULL, 128},
+	{ "",                              NULL, GTK_SIGNAL_FUNC(NULL),                       NULL, 1},
+	{ N_("Remove This Column"),        NULL, GTK_SIGNAL_FUNC(ethi_popup_remove_column),   NULL, 8},
+	{ N_("Add a Column..."),           NULL, GTK_SIGNAL_FUNC(ethi_popup_field_chooser),   NULL, 0},
+	{ "",                              NULL, GTK_SIGNAL_FUNC(NULL),                       NULL, 1},
+	{ N_("Alignment"),                 NULL, GTK_SIGNAL_FUNC(ethi_popup_alignment),       NULL, 128},
+	{ N_("Best Fit"),                  NULL, GTK_SIGNAL_FUNC(ethi_popup_best_fit),        NULL, 2},
+	{ N_("Format Columns..."),         NULL, GTK_SIGNAL_FUNC(ethi_popup_format_columns),  NULL, 128},
+	{ "",                              NULL, GTK_SIGNAL_FUNC(NULL),                       NULL, 1},
+	{ N_("Customize Current View..."), NULL, GTK_SIGNAL_FUNC(ethi_popup_customize_view),  NULL, 4},
+	{ NULL, NULL, NULL, NULL, 0 }
 };
 
 static void
@@ -1481,21 +1474,16 @@ ethi_header_context_menu (ETableHeaderItem *ethi, GdkEventButton *event)
 {
 	EthiHeaderInfo *info = g_new(EthiHeaderInfo, 1);
 	ETableCol *col;
-	GtkMenu *popup;
 	info->ethi = ethi;
 	info->col = ethi_find_col_by_x (ethi, event->x);
 	col = e_table_header_get_column (ethi->eth, info->col);
-
-	popup = e_popup_menu_create_with_domain (ethi_context_menu,
-						 1 +
-						 (col->sortable ? 0 : 2) +
-						 ((ethi->table || ethi->tree) ? 0 : 4) + 
-						 ((e_table_header_count (ethi->eth) > 1) ? 0 : 8),
-						 ((e_table_sort_info_get_can_group (ethi->sort_info)) ? 0 : 16) +
-						 128, info, E_I18N_DOMAIN);
-	gtk_signal_connect (GTK_OBJECT (popup), "selection-done",
-			    GTK_SIGNAL_FUNC (free_popup_info), info);
-	e_popup_menu (popup, (GdkEvent *) event);
+	e_popup_menu_run (ethi_context_menu, (GdkEvent *) event,
+			  1 +
+			  (col->sortable ? 0 : 2) +
+			  ((ethi->table || ethi->tree) ? 0 : 4) + 
+			  ((e_table_header_count (ethi->eth) > 1) ? 0 : 8),
+			  ((e_table_sort_info_get_can_group (ethi->sort_info)) ? 0 : 16) +
+			  128, info);
 }
 
 static void
@@ -1753,8 +1741,8 @@ ethi_class_init (GtkObjectClass *object_class)
 				GTK_RUN_LAST,
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETableHeaderItemClass, button_pressed),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_GDK_EVENT);
+				e_marshal_NONE__BOXED,
+				GTK_TYPE_NONE, 1, GDK_TYPE_EVENT);
 		
 	E_OBJECT_CLASS_ADD_SIGNALS (object_class, ethi_signals, LAST_SIGNAL);
 }
