@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-subset-variable.c
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -28,7 +28,7 @@
 #include "gal/util/e-util.h"
 #include "e-table-subset-variable.h"
 
-#define ETSSV_CLASS(e) ((ETableSubsetVariableClass *)((GtkObject *)e)->klass)
+#define ETSSV_CLASS(e) ((ETableSubsetVariableClass *)(GTK_OBJECT_GET_CLASS (e)))
 
 #define PARENT_TYPE E_TABLE_SUBSET_TYPE
 
@@ -130,7 +130,7 @@ etssv_class_init (GtkObjectClass *object_class)
 	klass->remove  = etssv_remove;
 }
 
-E_MAKE_TYPE(e_table_subset_variable, "ETableSubsetVariable", ETableSubsetVariable, etssv_class_init, NULL, PARENT_TYPE)
+E_MAKE_TYPE(e_table_subset_variable, "ETableSubsetVariable", ETableSubsetVariable, etssv_class_init, NULL, PARENT_TYPE);
 
 ETableModel *
 e_table_subset_variable_construct (ETableSubsetVariable *etssv,
@@ -202,21 +202,6 @@ e_table_subset_variable_remove    (ETableSubsetVariable *etssv,
 		return FALSE;
 }
 
-void
-e_table_subset_variable_clear (ETableSubsetVariable *etssv)
-{
-	ETableModel *etm = E_TABLE_MODEL(etssv);
-	ETableSubset *etss = E_TABLE_SUBSET(etssv);
-
-	e_table_model_pre_change (etm);
-	etss->n_map = 0;
-	g_free (etss->map_table);
-	etss->map_table = g_new (unsigned int, 1);
-	etssv->n_vals_allocated = 1;
-	
-	e_table_model_changed (etm);
-}
-
 void
 e_table_subset_variable_increment (ETableSubsetVariable *etssv,
 				   gint                  position,
