@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-table-subset.c - Implements a table that contains a subset of another table.
  * Copyright 1999, 2000, 2001, Ximian, Inc.
  *
@@ -41,10 +41,7 @@ static void etss_proxy_model_rows_deleted_real (ETableSubset *etss, ETableModel
 
 static ETableModelClass *etss_parent_class;
 
-#define ETSS_CLASS(object) (E_TABLE_SUBSET_CLASS(GTK_OBJECT(object)->klass))
-
-#define VALID_ROW(etss, row) (row >= -1 && row < etss->n_map)
-#define MAP_ROW(etss, row) (row == -1 ? -1 : etss->map_table[row])
+#define ETSS_CLASS(object) (E_TABLE_SUBSET_CLASS(GTK_OBJECT_GET_CLASS(object)))
 
 static gint
 etss_get_view_row (ETableSubset *etss, int row)
@@ -115,6 +112,7 @@ etss_destroy (GtkObject *object)
 	}
 
 	g_free (etss->map_table);
+	etss->map_table = NULL;
 
 	GTK_OBJECT_CLASS (etss_parent_class)->destroy (object);
 }
@@ -140,11 +138,9 @@ etss_value_at (ETableModel *etm, int col, int row)
 {
 	ETableSubset *etss = (ETableSubset *)etm;
 
-	g_return_val_if_fail (VALID_ROW (etss, row), NULL);
-
 	etss->last_access = row;
 	d(g_print("g) Setting last_access to %d\n", row));
-	return e_table_model_value_at (etss->source, col, MAP_ROW(etss, row));
+	return e_table_model_value_at (etss->source, col, etss->map_table [row]);
 }
 
 static void
@@ -152,11 +148,9 @@ etss_set_value_at (ETableModel *etm, int col, int row, const void *val)
 {
 	ETableSubset *etss = (ETableSubset *)etm;
 
-	g_return_if_fail (VALID_ROW (etss, row));
-
 	etss->last_access = row;
 	d(g_print("h) Setting last_access to %d\n", row));
-	e_table_model_set_value_at (etss->source, col, MAP_ROW(etss, row), val);
+	e_table_model_set_value_at (etss->source, col, etss->map_table [row], val);
 }
 
 static gboolean
@@ -164,15 +158,15 @@ etss_is_cell_editable (ETableModel *etm, int col, int row)
 {
 	ETableSubset *etss = (ETableSubset *)etm;
 
-	g_return_val_if_fail (VALID_ROW (etss, row), FALSE);
-
-	return e_table_model_is_cell_editable (etss->source, col, MAP_ROW(etss, row));
+	return e_table_model_is_cell_editable (etss->source, col, etss->map_table [row]);
 }
 
 static gboolean
 etss_has_save_id (ETableModel *etm)
 {
-	return TRUE;
+	ETableSubset *etss = (ETableSubset *)etm;
+
+	return e_table_model_has_save_id (etss->source);
 }
 
 static char *
@@ -180,12 +174,7 @@ etss_get_save_id (ETableModel *etm, int row)
 {
 	ETableSubset *etss = (ETableSubset *)etm;
 
-	g_return_val_if_fail (VALID_ROW (etss, row), NULL);
-
-	if (e_table_model_has_save_id (etss->source))
-		return e_table_model_get_save_id (etss->source, MAP_ROW(etss, row));
-	else
-		return g_strdup_printf ("%d", MAP_ROW(etss, row));
+	return e_table_model_get_save_id (etss->source, etss->map_table [row]);
 }
 
 static void
@@ -238,35 +227,35 @@ etss_value_to_string (ETableModel *etm, int col, const void *value)
 static void
 etss_class_init (GtkObjectClass *object_class)
 {
-	ETableSubsetClass *klass         = (ETableSubsetClass *) object_class;
-	ETableModelClass *table_class    = (ETableModelClass *) object_class;
+	ETableSubsetClass *klass        = (ETableSubsetClass *) object_class;
+	ETableModelClass *table_class   = (ETableModelClass *) object_class;
 
-	etss_parent_class                = gtk_type_class (PARENT_TYPE);
+	etss_parent_class               = gtk_type_class (PARENT_TYPE);
 	
-	object_class->destroy            = etss_destroy;
+	object_class->destroy           = etss_destroy;
 
-	table_class->column_count        = etss_column_count;
-	table_class->row_count           = etss_row_count;
-	table_class->append_row          = etss_append_row;
+	table_class->column_count       = etss_column_count;
+	table_class->row_count          = etss_row_count;
+	table_class->append_row         = etss_append_row;
 
-	table_class->value_at            = etss_value_at;
-	table_class->set_value_at        = etss_set_value_at;
-	table_class->is_cell_editable    = etss_is_cell_editable;
+	table_class->value_at           = etss_value_at;
+	table_class->set_value_at       = etss_set_value_at;
+	table_class->is_cell_editable   = etss_is_cell_editable;
 
-	table_class->has_save_id         = etss_has_save_id;
-	table_class->get_save_id         = etss_get_save_id;
+	table_class->has_save_id        = etss_has_save_id;
+	table_class->get_save_id        = etss_get_save_id;
 
-	table_class->duplicate_value     = etss_duplicate_value;
-	table_class->free_value          = etss_free_value;
-	table_class->initialize_value    = etss_initialize_value;
-	table_class->value_is_empty      = etss_value_is_empty;
-	table_class->value_to_string     = etss_value_to_string;
+	table_class->duplicate_value    = etss_duplicate_value;
+	table_class->free_value         = etss_free_value;
+	table_class->initialize_value   = etss_initialize_value;
+	table_class->value_is_empty     = etss_value_is_empty;
+	table_class->value_to_string    = etss_value_to_string;
 
-	klass->proxy_model_pre_change    = etss_proxy_model_pre_change_real;
+	klass->proxy_model_pre_change   = etss_proxy_model_pre_change_real;
 	klass->proxy_model_no_change     = etss_proxy_model_no_change_real;
-	klass->proxy_model_changed       = etss_proxy_model_changed_real;
-	klass->proxy_model_row_changed   = etss_proxy_model_row_changed_real;
-	klass->proxy_model_cell_changed  = etss_proxy_model_cell_changed_real;
+	klass->proxy_model_changed      = etss_proxy_model_changed_real;
+	klass->proxy_model_row_changed  = etss_proxy_model_row_changed_real;
+	klass->proxy_model_cell_changed = etss_proxy_model_cell_changed_real;
 	klass->proxy_model_rows_inserted = etss_proxy_model_rows_inserted_real;
 	klass->proxy_model_rows_deleted  = etss_proxy_model_rows_deleted_real;
 }
@@ -277,7 +266,7 @@ etss_init (ETableSubset *etss)
 	etss->last_access = 0;
 }
 
-E_MAKE_TYPE(e_table_subset, "ETableSubset", ETableSubset, etss_class_init, etss_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_subset, "ETableSubset", ETableSubset, etss_class_init, etss_init, PARENT_TYPE);
 
 static void
 etss_proxy_model_pre_change_real (ETableSubset *etss, ETableModel *etm)
@@ -399,20 +388,20 @@ e_table_subset_construct (ETableSubset *etss, ETableModel *source, int nvals)
 	for (i = 0; i < nvals; i++)
 		etss->map_table [i] = i;
 
-	etss->table_model_pre_change_id    = gtk_signal_connect (GTK_OBJECT (source), "model_pre_change",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_pre_change), etss);
+	etss->table_model_pre_change_id = gtk_signal_connect (GTK_OBJECT (source), "model_pre_change",
+							      GTK_SIGNAL_FUNC (etss_proxy_model_pre_change), etss);
 	etss->table_model_no_change_id     = gtk_signal_connect (GTK_OBJECT (source), "model_no_change",
 								 GTK_SIGNAL_FUNC (etss_proxy_model_no_change), etss);
-	etss->table_model_changed_id       = gtk_signal_connect (GTK_OBJECT (source), "model_changed",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_changed), etss);
-	etss->table_model_row_changed_id   = gtk_signal_connect (GTK_OBJECT (source), "model_row_changed",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_row_changed), etss);
-	etss->table_model_cell_changed_id  = gtk_signal_connect (GTK_OBJECT (source), "model_cell_changed",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_cell_changed), etss);
+	etss->table_model_changed_id = gtk_signal_connect (GTK_OBJECT (source), "model_changed",
+						     GTK_SIGNAL_FUNC (etss_proxy_model_changed), etss);
+	etss->table_model_row_changed_id = gtk_signal_connect (GTK_OBJECT (source), "model_row_changed",
+							 GTK_SIGNAL_FUNC (etss_proxy_model_row_changed), etss);
+	etss->table_model_cell_changed_id = gtk_signal_connect (GTK_OBJECT (source), "model_cell_changed",
+							  GTK_SIGNAL_FUNC (etss_proxy_model_cell_changed), etss);
 	etss->table_model_rows_inserted_id = gtk_signal_connect (GTK_OBJECT (source), "model_rows_inserted",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_rows_inserted), etss);
-	etss->table_model_rows_deleted_id  = gtk_signal_connect (GTK_OBJECT (source), "model_rows_deleted",
-								 GTK_SIGNAL_FUNC (etss_proxy_model_rows_deleted), etss);
+								GTK_SIGNAL_FUNC (etss_proxy_model_rows_inserted), etss);
+	etss->table_model_rows_deleted_id = gtk_signal_connect (GTK_OBJECT (source), "model_rows_deleted",
+							       GTK_SIGNAL_FUNC (etss_proxy_model_rows_deleted), etss);
 	
 	return E_TABLE_MODEL (etss);
 }
