@@ -30,16 +30,15 @@
 
 #include "e-icon-bar.h"
 
-#include <gtk/gtkdnd.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtksignal.h>
-#include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 #include "e-icon-bar-bg-item.h"
+#include <gal/util/e-util.h>
 #include <gal/e-text/e-text.h>
 #include <gal/widgets/e-canvas-utils.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
-#include "gal/util/e-util.h"
+#include <libgnomecanvas/gnome-canvas-pixbuf.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
 
 /* These are the offsets of the icons & text in both views. Note that the
    shadow around icons is drawn in the space between items (as is the
@@ -189,8 +188,8 @@ e_icon_bar_class_init (EIconBarClass *class)
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EIconBarClass,
 						   selected_item),
-				gtk_marshal_NONE__POINTER_INT,
-				GTK_TYPE_NONE, 2, GTK_TYPE_GDK_EVENT,
+				e_marshal_NONE__BOXED_INT,
+				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
 				GTK_TYPE_INT);
 	e_icon_bar_signals[ITEM_DRAGGED] =
 		gtk_signal_new ("item_dragged",
@@ -198,8 +197,8 @@ e_icon_bar_class_init (EIconBarClass *class)
 				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EIconBarClass,
 						   dragged_item),
-				gtk_marshal_NONE__POINTER_INT,
-				GTK_TYPE_NONE, 2, GTK_TYPE_GDK_EVENT,
+				e_marshal_NONE__BOXED_INT,
+				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
 				GTK_TYPE_INT);
 
 	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_icon_bar_signals,
@@ -271,11 +270,7 @@ e_icon_bar_init (EIconBar *icon_bar)
 					     E_ICON_BAR_COLOR_LAST, FALSE,
 					     TRUE, success);
 	if (nfailed)
-		g_warning ("EIconBar failed to allocate all colors");
-
-	gtk_drag_dest_set (GTK_WIDGET (icon_bar),
-			   0, NULL, 0,
-			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
+		g_warning ("Failed to allocate all colors");
 }
 
 
@@ -305,15 +300,18 @@ e_icon_bar_destroy (GtkObject *object)
 
 	icon_bar = E_ICON_BAR (object);
 
-	for (item_num = 0; item_num < icon_bar->items->len; item_num++) {
-		item = &g_array_index (icon_bar->items,
-				       EIconBarItem, item_num);
-		if (item->destroy)
-			item->destroy (item->data);
+	if (icon_bar->items) {
+		for (item_num = 0; item_num < icon_bar->items->len; item_num++) {
+			item = &g_array_index (icon_bar->items,
+					       EIconBarItem, item_num);
+			if (item->destroy)
+				item->destroy (item->data);
+		}
+		
+		g_array_free (icon_bar->items, TRUE);
+		icon_bar->items = NULL;
 	}
 
-	g_array_free (icon_bar->items, TRUE);
-
 	if (icon_bar->auto_scroll_timeout_id != 0) {
 		gtk_timeout_remove (icon_bar->auto_scroll_timeout_id);
 		icon_bar->auto_scroll_timeout_id = 0;
@@ -328,7 +326,9 @@ e_icon_bar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
 	EIconBar *icon_bar;
 	gint canvas_width, canvas_height, height;
-
+#if 0
+	g_print ("In e_icon_bar_size_allocate\n");
+#endif
 	icon_bar = E_ICON_BAR (widget);
 
 	GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
@@ -407,14 +407,14 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 		max_lines = 2;
 		text_x = icon_bar->text_x + (icon_bar->text_w / 2);
 		line_wrap = TRUE;
-		font = GTK_WIDGET (icon_bar)->style->font;
+		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
 		text_h = font->ascent + font->descent;
 	} else {
 		justify = GTK_JUSTIFY_LEFT;
 		anchor = GTK_ANCHOR_NW;
 		max_lines = 1;
 		text_x = icon_bar->text_x;
-		font = GTK_WIDGET (icon_bar)->style->font;
+		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
 		text_h = font->ascent + font->descent;
 		line_wrap = FALSE;
 	}
@@ -596,7 +596,7 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 				       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : item->pixbuf,
 				       NULL);
 		gnome_canvas_item_set (item->text,
-				       "font_gdk", style->font,
+				       "font_gdk", gtk_style_get_font (style),
 				       "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
 				       NULL);
 
@@ -653,7 +653,7 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 
 	gtk_widget_ensure_style (GTK_WIDGET (icon_bar));
 	style = GTK_WIDGET (icon_bar)->style;
-	font = style->font;
+	font = gtk_style_get_font (style);
 	clip_height = max_lines * (font->ascent + font->descent);
 	item.text = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (icon_bar)->root),
 					   e_text_get_type (),
@@ -681,7 +681,7 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 
 	item.pixbuf = image;
 	if (image)
-		gdk_pixbuf_ref (image);
+	gdk_pixbuf_ref (image);
 
 	flattened = flatten_alpha (image,
 				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
@@ -983,6 +983,7 @@ static void
 e_icon_bar_reflow (ECanvas *canvas)
 {
 #if 0
+	g_print ("In e_icon_bar_on_canvas_reflow\n");
 	gtk_widget_queue_resize (GTK_WIDGET (canvas));
 #endif
 }
@@ -1095,6 +1096,9 @@ e_icon_bar_item_pressed (EIconBar *icon_bar,
 
 	if (button == 1 && item_num != -1) {
 		icon_bar->mouse_over_item_num = item_num;
+#if 0
+		g_print ("Set mouse_over_item_num: %i\n", icon_bar->mouse_over_item_num);
+#endif
 		icon_bar->pressed_item_num = item_num;
 		icon_bar->pressed_x = event->button.x;
 		icon_bar->pressed_y = event->button.y;
@@ -1150,6 +1154,10 @@ e_icon_bar_item_motion (EIconBar *icon_bar,
 {
 	gboolean need_redraw = TRUE;
 
+#if 0
+	g_print ("In e_icon_bar_item_motion\n");
+#endif
+
 	if (event && event->motion.state & GDK_BUTTON1_MASK
 	    && icon_bar->pressed_item_num != -1) {
 		if (icon_bar->enable_drags
@@ -1188,6 +1196,9 @@ e_icon_bar_item_motion (EIconBar *icon_bar,
 	}
 
 	icon_bar->mouse_over_item_num = item_num;
+#if 0
+	g_print ("Set mouse_over_item_num: %i\n", icon_bar->mouse_over_item_num);
+#endif
 
 	if (need_redraw)
 		gtk_widget_queue_draw (GTK_WIDGET (icon_bar));
@@ -1545,9 +1556,7 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 			guint           time)
 {
 	EIconBar *icon_bar;
-	GdkDragAction action;
-	gint item_num, before_item;
-	gint scroll_x, scroll_y;
+	gint item_num, before_item, scroll_x, scroll_y;
 
 	g_return_val_if_fail (E_IS_ICON_BAR (widget), FALSE);
 
@@ -1565,8 +1574,6 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 	e_icon_bar_item_motion (icon_bar, item_num, NULL);
 	e_icon_bar_set_dragging_before_item (icon_bar, before_item);
 
-	action = 0;
-
 	/* Check if the mouse is at the top or bottom of the bar, and if it is
 	   scroll up/down. */
 	if (y < E_ICON_BAR_DRAG_AUTO_SCROLL_OFFSET)
@@ -1578,7 +1585,7 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 			gtk_timeout_remove (icon_bar->auto_scroll_timeout_id);
 			icon_bar->auto_scroll_timeout_id = 0;
 		}
-		return TRUE;
+		return FALSE;
 	}
 
 	if (icon_bar->auto_scroll_timeout_id == 0) {
@@ -1586,7 +1593,7 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 		icon_bar->auto_scroll_delay = E_ICON_BAR_SCROLL_DELAY;
 	}
 
-	return TRUE;
+	return FALSE;
 }
 
 
@@ -1610,6 +1617,9 @@ e_icon_bar_drag_leave (GtkWidget      *widget,
 
 	if (icon_bar->mouse_over_item_num != -1) {
 		icon_bar->mouse_over_item_num = -1;
+#if 0
+		g_print ("Set mouse_over_item_num: %i\n", icon_bar->mouse_over_item_num);
+#endif
 		gtk_widget_queue_draw (GTK_WIDGET (icon_bar));
 	}
 }
