@@ -1,25 +1,24 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /* 
- * Author : 
- *  Damon Chaplin <damon@helixcode.com>
+ * e-shortcut-model.c
+ * Copyright 1999, 2000, 2001, Ximian, Inc.
  *
- * Copyright 1999, Helix Code, Inc.
+ * Authors:
+ *   Damon Chaplin <damon@ximian.com>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 /*
@@ -53,7 +52,7 @@ struct _EShortcutModelGroup
 	GArray *items;
 };
 
-#define ESM_CLASS(e) ((EShortcutModelClass *)((GtkObject *)e)->klass)
+#define ESM_CLASS(e) ((EShortcutModelClass *)(GTK_OBJECT_GET_CLASS (e)))
 
 
 static void e_shortcut_model_class_init	(EShortcutModelClass *class);
@@ -83,14 +82,6 @@ static void e_shortcut_model_real_update_item   (EShortcutModel *shortcut_model,
 						 const gchar    *item_url,
 						 const gchar    *item_name,
 						 GdkPixbuf      *item_image);
-static void e_shortcut_model_marshal1		(GtkObject	*object,
-						 GtkSignalFunc	 func,
-						 gpointer	 func_data,
-						 GtkArg		*args);
-static void e_shortcut_model_marshal2		(GtkObject	*object,
-						 GtkSignalFunc   func,
-						 gpointer	 func_data,
-						 GtkArg		*args);
 
 static gint e_shortcut_model_real_get_num_groups(EShortcutModel *shortcut_model);
 static gint e_shortcut_model_real_get_num_items	(EShortcutModel *shortcut_model,
@@ -137,17 +128,17 @@ e_shortcut_model_class_init	(EShortcutModelClass	*class)
 	e_shortcut_model_signals[GROUP_ADDED] =
 		gtk_signal_new ("group_added",
 				GTK_RUN_FIRST | GTK_RUN_ACTION,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EShortcutModelClass,
 						   group_added),
-				e_shortcut_model_marshal1,
+				e_marshal_NONE__INT_STRING,
 				GTK_TYPE_NONE, 2,
 				GTK_TYPE_INT, GTK_TYPE_STRING);
 
 	e_shortcut_model_signals[GROUP_REMOVED] =
 		gtk_signal_new ("group_removed",
 				GTK_RUN_FIRST | GTK_RUN_ACTION,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EShortcutModelClass,
 						   group_removed),
 				gtk_marshal_NONE__INT,
@@ -157,10 +148,10 @@ e_shortcut_model_class_init	(EShortcutModelClass	*class)
 	e_shortcut_model_signals[ITEM_ADDED] =
 		gtk_signal_new ("item_added",
 				GTK_RUN_FIRST | GTK_RUN_ACTION,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EShortcutModelClass,
 						   item_added),
-				e_shortcut_model_marshal2,
+				e_marshal_NONE__INT_INT_STRING_STRING_POINTER,
 				GTK_TYPE_NONE, 5,
 				GTK_TYPE_INT, GTK_TYPE_INT,
 				GTK_TYPE_STRING, GTK_TYPE_STRING, GTK_TYPE_POINTER);
@@ -168,7 +159,7 @@ e_shortcut_model_class_init	(EShortcutModelClass	*class)
 	e_shortcut_model_signals[ITEM_REMOVED] =
 		gtk_signal_new ("item_removed",
 				GTK_RUN_FIRST | GTK_RUN_ACTION,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EShortcutModelClass,
 						   item_removed),
 				gtk_marshal_NONE__INT_INT,
@@ -178,15 +169,15 @@ e_shortcut_model_class_init	(EShortcutModelClass	*class)
 	e_shortcut_model_signals[ITEM_UPDATED] =
 		gtk_signal_new ("item_updated",
 				GTK_RUN_FIRST | GTK_RUN_ACTION,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (EShortcutModelClass,
 						   item_updated),
-				e_shortcut_model_marshal2,
+				e_marshal_NONE__INT_INT_STRING_STRING_POINTER,
 				GTK_TYPE_NONE, 5,
 				GTK_TYPE_INT, GTK_TYPE_INT,
 				GTK_TYPE_STRING, GTK_TYPE_STRING, GTK_TYPE_POINTER);
 
-	gtk_object_class_add_signals (object_class, e_shortcut_model_signals,
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_shortcut_model_signals,
 				      LAST_SIGNAL);
 
 	/* Method override */
@@ -232,12 +223,14 @@ e_shortcut_model_destroy	(GtkObject	*object)
 
 	shortcut_model = E_SHORTCUT_MODEL (object);
 
-	num_groups = shortcut_model->groups->len;
-	for (group_num = 0; group_num < num_groups; group_num++)
-		e_shortcut_model_free_group (shortcut_model, group_num);
+	if (shortcut_model->groups) {
+		num_groups = shortcut_model->groups->len;
+		for (group_num = 0; group_num < num_groups; group_num++)
+			e_shortcut_model_free_group (shortcut_model, group_num);
 
-	g_array_free (shortcut_model->groups, TRUE);
-	shortcut_model->groups = NULL;
+		g_array_free (shortcut_model->groups, TRUE);
+		shortcut_model->groups = NULL;
+	}
 
 	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
@@ -501,34 +494,6 @@ e_shortcut_model_update_item (EShortcutModel *shortcut_model,
 			 group_num, item_num, item_url, item_name, item_image);
 }
 
-static void
-e_shortcut_model_marshal1	(GtkObject	*object,
-				 GtkSignalFunc	 func,
-				 gpointer	 func_data,
-				 GtkArg		*args)
-{
-	void (*rfunc) (GtkObject*, gint, gpointer, gpointer);
-	rfunc = (void (*) (GtkObject*, gint, gpointer, gpointer)) func;
-	(*rfunc) (object, GTK_VALUE_INT (args[0]), GTK_VALUE_STRING (args[1]),
-		  func_data);
-}
-
-
-static void
-e_shortcut_model_marshal2	(GtkObject	*object,
-				 GtkSignalFunc   func,
-				 gpointer	 func_data,
-				 GtkArg		*args)
-{
-	void (*rfunc) (GtkObject*, gint, gint, gpointer, gpointer, gpointer, gpointer);
-	rfunc = (void (*) (GtkObject*, gint, gint, gpointer, gpointer, gpointer,
-			   gpointer)) func;
-	(*rfunc) (object, GTK_VALUE_INT (args[0]), GTK_VALUE_INT (args[1]),
-		  GTK_VALUE_STRING (args[2]), GTK_VALUE_STRING (args[3]), GTK_VALUE_POINTER (args[4]),
-		  func_data);
-}
-
-
 gint
 e_shortcut_model_get_num_groups	(EShortcutModel *shortcut_model)
 {
@@ -645,6 +610,6 @@ e_shortcut_model_real_get_item_info	(EShortcutModel *shortcut_model,
 		*item_name = g_strdup (item->name);
 
 	if (item_image)
-		*item_image = gdk_pixbuf_ref (item->image);
+		*item_image = item->image ? gdk_pixbuf_ref (item->image) : NULL;
 }
 
