@@ -1,50 +1,69 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * color-group.c : Utility to keep a shered memory of custom colors
+ * color-group.c - Utility to keep a shered memory of custom colors
  *                 between arbitrary widgets.
+ * Copyright 2000, Michael Levy
+ * Copyright 2001, Almer S. Tigelaar
  *
- * Author:
+ * Authors:
  * 	Michael Levy (mlevy@genoscope.cns.fr)
  * Revised and polished by:
- *      Almer S. Tigelaar (almer@gnome.org>
+ *   Almer S. Tigelaar <almer@gnome.org>
  *
- * (C) 2000 Michael Levy
- * (C) 2001 Almer S. Tigelaar
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
-#include <string.h>
-#include <gtk/gtksignal.h>
-#include "gal/util/e-util.h"
 #include "color-group.h"
+#include <glib-object.h>
+#include <gdk/gdkcolor.h>
+#include "gal/util/e-util.h"
+#include <string.h>
 
-#define PARENT_TYPE gtk_object_get_type ()
-#define PARENT_CLASS gtk_type_class ( gtk_object_get_type ())
+#define PARENT_TYPE	(G_TYPE_OBJECT)
+#define PARENT_CLASS	gtk_type_class ( gtk_object_get_type ())
 
 enum {
         CUSTOM_COLOR_ADD,
         LAST_SIGNAL
 };
 
-static gint color_group_signals [LAST_SIGNAL] = { 0 };
+static GObjectClass *parent_class;
 
-static void color_group_destroy(GtkObject *obj);
+static GQuark color_group_signals [LAST_SIGNAL] = { 0 };
+
+static void color_group_finalize (GObject *obj);
 
 static void
-color_group_class_init (ColorGroupClass *class)
+color_group_class_init (ColorGroupClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 
-	object_class = (GtkObjectClass*) class;
+	object_class = (GObjectClass*) klass;
 	
-	object_class->destroy = &color_group_destroy;
+	object_class->finalize = &color_group_finalize;
+	parent_class = g_type_class_peek (PARENT_TYPE);
 
-	color_group_signals[CUSTOM_COLOR_ADD] =
-		gtk_signal_new("custom_color_add",
-			       GTK_RUN_LAST,
-			       object_class->type,
-			       GTK_SIGNAL_OFFSET (ColorGroupClass, custom_color_add),
-			       gtk_marshal_NONE__POINTER,
-			       GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-	gtk_object_class_add_signals (object_class, color_group_signals, LAST_SIGNAL);
+	color_group_signals [CUSTOM_COLOR_ADD] =
+		g_signal_new ("custom_color_add",
+			COLOR_GROUP_TYPE,
+			G_SIGNAL_RUN_LAST,
+			G_STRUCT_OFFSET (ColorGroupClass, custom_color_add),
+			(GSignalAccumulator) NULL, NULL,
+			g_cclosure_marshal_VOID__POINTER,
+			G_TYPE_NONE,
+			1, G_TYPE_POINTER);
 }
 
 static void
@@ -72,6 +91,7 @@ cg_hash (gconstpointer	key)
 	/* Do NOT use smart type checking it will not work for the tmp_key */
 	return g_str_hash (((ColorGroup *)key)->name);
 }
+
 static gint
 cg_cmp (gconstpointer a, gconstpointer	b)
 {
@@ -138,7 +158,7 @@ create_unique_name (gpointer context)
 }
 
 static void
-color_group_destroy (GtkObject *obj)
+color_group_finalize (GObject *obj)
 {
 	ColorGroup *cg;
 
@@ -146,21 +166,26 @@ color_group_destroy (GtkObject *obj)
 	g_return_if_fail(IS_COLOR_GROUP(obj));
 	g_assert(group_names != NULL);
 
-	cg = COLOR_GROUP(obj);
+	cg = COLOR_GROUP (obj);
 
 	/* make this name available */
-	g_hash_table_remove (group_names, cg);
-	g_free (cg->name);
+	if (cg->name) {
+		g_hash_table_remove (group_names, cg);
+		g_free (cg->name);
+		cg->name = NULL;
+	}
 
-	/* Free the whole colour history */
-	while ((int) cg->history->len > 0)
-		gdk_color_free ((GdkColor *) g_ptr_array_remove_index (cg->history, 0));
-	g_ptr_array_free (cg->history, TRUE);
-	cg->history = NULL;
+	if (cg->history) {
+		/* Free the whole colour history */
+		while ((int) cg->history->len > 0)
+			gdk_color_free ((GdkColor *)
+					g_ptr_array_remove_index (cg->history, 0));
+		g_ptr_array_free (cg->history, TRUE);
+		cg->history = NULL;
+	}
 	
-	/* call the base class destructor */
-	if (GTK_OBJECT_CLASS (PARENT_CLASS)->destroy)
-		(* GTK_OBJECT_CLASS (PARENT_CLASS)->destroy) (obj);
+	if (parent_class->finalize)
+		(parent_class->finalize) (obj);
 }
 
 /*
@@ -218,12 +243,12 @@ color_group_fetch (const gchar *name, gpointer context)
 	cg = color_group_get (new_name, context);
 	if (cg != NULL) {
 		g_free (new_name);
-		gtk_object_ref (GTK_OBJECT(cg));
+		g_object_ref (G_OBJECT (cg));
 		return cg;
 	}
 
 	/* Take care of creating the new object */
-	cg = gtk_type_new (color_group_get_type ());
+	cg = g_object_new (color_group_get_type (), NULL);
 	g_return_val_if_fail(cg != NULL, NULL);
 
 	cg->name = new_name;
@@ -302,7 +327,8 @@ color_group_add_color (ColorGroup *cg, GdkColor const * const color)
 	/* Tell color-palette's that use this group that
 	 * a new custom color was added.
 	 */
-	gtk_signal_emit(GTK_OBJECT(cg),
-			color_group_signals[CUSTOM_COLOR_ADD],
-			color);
+	g_signal_emit (G_OBJECT(cg),
+		color_group_signals [CUSTOM_COLOR_ADD],
+		0,
+		color);
 }
