@@ -24,7 +24,7 @@
 #ifndef __E_REFLOW_H__
 #define __E_REFLOW_H__
 
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include <gal/widgets/e-reflow-model.h>
 #include <gal/widgets/e-selection-model.h>
 #include <gal/util/e-sorter-array.h>
